@@ -101,6 +101,8 @@ static CPUGraph * create_gui( XfcePanelPlugin * plugin )
 	base->plugin = plugin;
 
 	ebox = gtk_event_box_new();
+	gtk_event_box_set_visible_window(GTK_EVENT_BOX(ebox), FALSE);
+	gtk_event_box_set_above_child(GTK_EVENT_BOX(ebox), TRUE);
 	gtk_container_add( GTK_CONTAINER( plugin ), ebox );
 	xfce_panel_plugin_add_action_widget( plugin, ebox );
 	g_signal_connect( ebox, "button-press-event", G_CALLBACK( command_cb ), base );
@@ -170,6 +172,11 @@ static void create_bars( CPUGraph *base )
 	for( i=0; i< n; i++ )
 	{
 		base->bars[i] = GTK_WIDGET(gtk_progress_bar_new());
+		/* Set bar colors */
+		gtk_widget_modify_bg(base->bars[i], GTK_STATE_PRELIGHT, &base->colors[4]);
+		gtk_widget_modify_bg(base->bars[i], GTK_STATE_SELECTED, &base->colors[4]);
+		gtk_widget_modify_base(base->bars[i], GTK_STATE_SELECTED, &base->colors[4]);
+
 		gtk_box_pack_end( GTK_BOX(base->box), base->bars[i], FALSE, FALSE, 0 );
 		gtk_widget_show( base->bars[i] );
 	}
@@ -247,6 +254,7 @@ static gboolean size_cb( XfcePanelPlugin *plugin, guint size, CPUGraph *base )
 
 	if( base->has_bars )
 		set_bars_size( base, size, orientation );
+	set_border( base, base->has_border );
 
 	return TRUE;
 }
@@ -258,13 +266,13 @@ static void set_bars_size( CPUGraph *base, gint size, GtkOrientation orientation
 	gint h, v;
 	if( orientation == GTK_ORIENTATION_HORIZONTAL )
 	{
-		h = BORDER;
-		v = size;
+		h = 8;
+		v = -1;
 	}
 	else
 	{
-		h = size;
-		v = BORDER;
+		h = -1;
+		v = 8;
 	}
 	n = nb_bars( base );
 	for( i=0; i < n ; i++ )
@@ -284,7 +292,7 @@ static void orientation_cb( XfcePanelPlugin * plugin, GtkOrientation orientation
 	xfce_hvbox_set_orientation( XFCE_HVBOX( base->box ), orientation );
 #endif
 	if( base->has_bars )
-		set_bars_orientation( base, orientation );
+		set_bars_orientation( base, panel_orientation );
 
 	size_cb( plugin, xfce_panel_plugin_get_size( base->plugin ), base);
 }
@@ -441,8 +449,11 @@ void set_bars( CPUGraph * base, gboolean bars)
 
 void set_border( CPUGraph *base, gboolean border )
 {
+	int border_width = (xfce_panel_plugin_get_size( base->plugin ) > 26 ? 2 : 1);
 	base->has_border = border;
-	gtk_container_set_border_width( GTK_CONTAINER( base->box ), border ? BORDER / 2 : 0 );
+	if (!base->has_border)
+		border_width = 0;
+	gtk_container_set_border_width( GTK_CONTAINER( base->box ), border_width);
 }
 
 void set_frame( CPUGraph *base, gboolean frame )
@@ -499,12 +510,26 @@ void set_mode( CPUGraph *base, guint mode )
 
 void set_color( CPUGraph *base, guint number, GdkColor color )
 {
+	guint i, n;
+
 	base->colors[number] = color;
 	if( number == 0 )
 	{
 		gtk_widget_modify_bg( base->draw_area, GTK_STATE_INSENSITIVE, &base->colors[0] );
 		gtk_widget_modify_bg( base->draw_area, GTK_STATE_NORMAL, &base->colors[0] );
 	}
+	if( number == 4 )
+	{
+		n = nb_bars( base );
+
+		for( i=0; i< n; i++ )
+		{
+			/* Set bar colors */
+			gtk_widget_modify_bg(base->bars[i], GTK_STATE_PRELIGHT, &base->colors[4]);
+			gtk_widget_modify_bg(base->bars[i], GTK_STATE_SELECTED, &base->colors[4]);
+			gtk_widget_modify_base(base->bars[i], GTK_STATE_SELECTED, &base->colors[4]);
+		}
+	}
 }
 
 void set_tracked_core( CPUGraph *base, guint core )
